@@ -1,6 +1,6 @@
 /*
     This file is part of darktable,
-    Copyright (C) 2024 darktable developers.
+    Copyright (C) 2024-2025 darktable developers.
 
     darktable is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -149,7 +149,8 @@ const char **description(dt_iop_module_t *self)
 {
   return dt_iop_set_description
     (self,
-     _("combine with elements from a processed image"),
+     _("combine the image with elements from another processed image\n"
+       "(move this module to after output color profile if you see banding)"),
      _("corrective and creative"),
      _("linear, RGB, scene-referred"),
      _("linear, RGB"),
@@ -268,7 +269,7 @@ static void _setup_overlay(dt_iop_module_t *self,
   dt_iop_overlay_gui_data_t *g = self->gui_data;
   dt_iop_overlay_data_t *data = piece->data;
 
-  const dt_imgid_t imgid = data->imgid;
+  dt_imgid_t imgid = data->imgid;
 
   if(!p || !dt_is_valid_imgid(imgid))
     return;
@@ -286,6 +287,7 @@ static void _setup_overlay(dt_iop_module_t *self,
     {
       image_exists = TRUE;
       p->imgid = new_imgid;
+      imgid = new_imgid;
       dt_dev_add_history_item(dev, self, TRUE);
       if(g)
         gtk_widget_queue_draw(GTK_WIDGET(g->area));
@@ -516,19 +518,19 @@ void process(dt_iop_module_t *self,
     case DT_SCALE_MAINMENU_ADVANCED:
       wbase = iw;
       hbase = ih;
-      if (data->scale_img == DT_SCALE_IMG_WIDTH)
+      if(data->scale_img == DT_SCALE_IMG_WIDTH)
       {
         sbase = iw;
         scale = (data->scale_svg == DT_SCALE_SVG_WIDTH)
           ? sbase / dimension.width : sbase / dimension.height;
       }
-      else if (data->scale_img == DT_SCALE_IMG_HEIGHT)
+      else if(data->scale_img == DT_SCALE_IMG_HEIGHT)
       {
         sbase = ih;
         scale = (data->scale_svg == DT_SCALE_SVG_WIDTH)
           ? sbase / dimension.width : sbase / dimension.height;
       }
-      else if (data->scale_img == DT_SCALE_IMG_LARGER)
+      else if(data->scale_img == DT_SCALE_IMG_LARGER)
       {
         sbase = (iw > ih) ? iw : ih;
         scale = (data->scale_svg == DT_SCALE_SVG_WIDTH)
@@ -584,17 +586,17 @@ void process(dt_iop_module_t *self,
       svg_calc_heightfromwidth = FALSE;
       break;
     case DT_SCALE_MAINMENU_ADVANCED:
-      if (data->scale_img == DT_SCALE_IMG_WIDTH)
+      if(data->scale_img == DT_SCALE_IMG_WIDTH)
       {
         svg_calc_base = iw * uscale;
         svg_calc_heightfromwidth = (data->scale_svg == DT_SCALE_SVG_WIDTH) ? TRUE : FALSE;
       }
-      else if (data->scale_img == DT_SCALE_IMG_HEIGHT)
+      else if(data->scale_img == DT_SCALE_IMG_HEIGHT)
       {
         svg_calc_base = ih * uscale;
         svg_calc_heightfromwidth = (data->scale_svg == DT_SCALE_SVG_WIDTH) ? TRUE : FALSE;
       }
-      else if (data->scale_img == DT_SCALE_IMG_LARGER)
+      else if(data->scale_img == DT_SCALE_IMG_LARGER)
       {
         svg_calc_base = ((iw > ih) ? iw : ih) * uscale;
         svg_calc_heightfromwidth = (data->scale_svg == DT_SCALE_SVG_WIDTH) ? TRUE : FALSE;
@@ -975,6 +977,14 @@ static void _signal_image_changed(gpointer instance, dt_iop_module_t *self)
     _clear_cache_entry(self, k);
 }
 
+static void _signal_module_moved(gpointer instance, dt_iop_module_t *self)
+{
+  if(!self) return;
+
+  _clear_cache_entry(self, self->multi_priority);
+  dt_dev_reprocess_all(self->dev);
+}
+
 static void _drag_and_drop_received(GtkWidget *widget,
                                     GdkDragContext *context,
                                     gint x,
@@ -1164,17 +1174,9 @@ void gui_init(dt_iop_module_t *self)
   gtk_widget_set_tooltip_text(g->scale, _("the scale of the overlay"));
   gtk_widget_set_tooltip_text(g->rotate, _("the rotation of the overlay"));
 
-  DT_CONTROL_SIGNAL_CONNECT(DT_SIGNAL_DEVELOP_MODULE_REMOVE, _module_remove_callback, self);
-
-  DT_CONTROL_SIGNAL_CONNECT(DT_SIGNAL_DEVELOP_IMAGE_CHANGED, _signal_image_changed, self);
-}
-
-void gui_cleanup(dt_iop_module_t *self)
-{
-  IOP_GUI_FREE;
-
-  DT_CONTROL_SIGNAL_DISCONNECT(_module_remove_callback, self);
-  DT_CONTROL_SIGNAL_DISCONNECT(_signal_image_changed, self);
+  DT_CONTROL_SIGNAL_HANDLE(DT_SIGNAL_DEVELOP_MODULE_REMOVE, _module_remove_callback);
+  DT_CONTROL_SIGNAL_HANDLE(DT_SIGNAL_DEVELOP_IMAGE_CHANGED, _signal_image_changed);
+  DT_CONTROL_SIGNAL_HANDLE(DT_SIGNAL_DEVELOP_MODULE_MOVED, _signal_module_moved);
 }
 
 // clang-format off
