@@ -1,6 +1,6 @@
 /*
     This file is part of darktable,
-    Copyright (C) 2011-2023 darktable developers.
+    Copyright (C) 2011-2025 darktable developers.
 
 
     darktable is free software: you can redistribute it and/or modify
@@ -16,9 +16,6 @@
     You should have received a copy of the GNU General Public License
     along with darktable.  If not, see <http://www.gnu.org/licenses/>.
 */
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
 #include "bauhaus/bauhaus.h"
 #include "common/darktable.h"
 #include "common/imagebuf.h"
@@ -111,8 +108,7 @@ int legacy_params(dt_iop_module_t *self,
     } dt_iop_rawdenoise_params_v1_t;
 
     const dt_iop_rawdenoise_params_v1_t *o = (dt_iop_rawdenoise_params_v1_t *)old_params;
-    dt_iop_rawdenoise_params_v2_t *n =
-      (dt_iop_rawdenoise_params_v2_t *)malloc(sizeof(dt_iop_rawdenoise_params_v2_t));
+    dt_iop_rawdenoise_params_v2_t *n = malloc(sizeof(dt_iop_rawdenoise_params_v2_t));
 
     n->threshold = o->threshold;
     for(int k = 0; k < DT_IOP_RAWDENOISE_BANDS; k++)
@@ -138,9 +134,9 @@ const char *name()
   return _("raw denoise");
 }
 
-const char **description(struct dt_iop_module_t *self)
+const char **description(dt_iop_module_t *self)
 {
-  return dt_iop_set_description(self, _("denoise the raw picture early in the pipeline"),
+  return dt_iop_set_description(self, _("denoise the raw image early in the pipeline"),
                                       _("corrective"),
                                       _("linear, raw, scene-referred"),
                                       _("linear, raw"),
@@ -222,12 +218,7 @@ static void wavelet_denoise(const float *const restrict in, float *const restric
 
     // collect one of the R/G1/G2/B channels into a monochrome image, applying sqrt() to the values as a
     // variance-stabilizing transform
-#ifdef _OPENMP
-#pragma omp parallel for default(none) \
-    dt_omp_firstprivate(in, fimg, roi, halfwidth) \
-    shared(c) \
-    schedule(static)
-#endif
+    DT_OMP_FOR()
     for(int row = c & 1; row < roi->height; row += 2)
     {
       float *const restrict fimgp = fimg + (size_t)row / 2 * halfwidth;
@@ -243,12 +234,7 @@ static void wavelet_denoise(const float *const restrict in, float *const restric
 
     // distribute the denoised data back out to the original R/G1/G2/B channel, squaring the resulting values to
     // undo the original transform
-#ifdef _OPENMP
-#pragma omp parallel for default(none) \
-    dt_omp_firstprivate(fimg, halfwidth, out, roi, size) \
-    shared(c) \
-    schedule(static)
-#endif
+    DT_OMP_FOR()
     for(int row = c & 1; row < roi->height; row += 2)
     {
       const float *const restrict fimgp = fimg + (size_t)row / 2 * halfwidth;
@@ -312,7 +298,7 @@ static void wavelet_denoise(const float *const restrict in, float *const restric
 
 static inline float vstransform(const float value)
 {
-  return sqrtf(MAX(0.0f, value));
+  return sqrtf(fmaxf(0.0f, value));
 }
 
 static void wavelet_denoise_xtrans(const float *const restrict in, float *const restrict out,
@@ -348,12 +334,7 @@ static void wavelet_denoise_xtrans(const float *const restrict in, float *const
     }
     const size_t nthreads = dt_get_num_threads();
     const size_t chunksize = (height + nthreads - 1) / nthreads;
-#ifdef _OPENMP
-#pragma omp parallel for default(none) \
-  dt_omp_firstprivate(fimg, height, in, roi, size, width, xtrans, nthreads, chunksize) \
-    shared(c) num_threads(nthreads) \
-    schedule(static)
-#endif
+    DT_OMP_FOR(num_threads(nthreads))
     for(size_t chunk = 0; chunk < nthreads; chunk++)
     {
       const size_t start = chunk * chunksize;
@@ -468,12 +449,7 @@ static void wavelet_denoise_xtrans(const float *const restrict in, float *const
 
     // distribute the denoised data back out to the original R/G/B channel, squaring the resulting values to
     // undo the original transform
-#ifdef _OPENMP
-#pragma omp parallel for default(none) \
-    dt_omp_firstprivate(height, fimg, roi, width, xtrans, c) \
-    dt_omp_sharedconst(out) \
-    schedule(static)
-#endif
+    DT_OMP_FOR()
     for(int row = 0; row < height; row++)
     {
       const float *const restrict fimgp = fimg + (size_t)row * width;
@@ -490,10 +466,10 @@ static void wavelet_denoise_xtrans(const float *const restrict in, float *const
   dt_free_align(img);
 }
 
-void process(struct dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, const void *const ivoid,
+void process(dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, const void *const ivoid,
              void *const ovoid, const dt_iop_roi_t *const roi_in, const dt_iop_roi_t *const roi_out)
 {
-  const dt_iop_rawdenoise_data_t *const restrict d = (dt_iop_rawdenoise_data_t *)piece->data;
+  const dt_iop_rawdenoise_data_t *const restrict d = piece->data;
 
   if(!(d->threshold > 0.0f))
   {
@@ -510,11 +486,11 @@ void process(struct dt_iop_module_t *self, dt_dev_pixelpipe_iop_t *piece, const
   }
 }
 
-void init(dt_iop_module_t *module)
+void init(dt_iop_module_t *self)
 {
-  dt_iop_default_init(module);
+  dt_iop_default_init(self);
 
-  dt_iop_rawdenoise_params_t *d = module->default_params;
+  dt_iop_rawdenoise_params_t *d = self->default_params;
 
   for(int k = 0; k < DT_IOP_RAWDENOISE_BANDS; k++)
   {
@@ -525,24 +501,24 @@ void init(dt_iop_module_t *module)
   }
 }
 
-void reload_defaults(dt_iop_module_t *module)
+void reload_defaults(dt_iop_module_t *self)
 {
   // can't be switched on for non-raw images:
-  module->hide_enable_button = !dt_image_is_raw(&module->dev->image_storage);
+  self->hide_enable_button = !dt_image_is_raw(&self->dev->image_storage);
 
-  if(module->widget)
+  if(self->widget)
   {
-    gtk_stack_set_visible_child_name(GTK_STACK(module->widget), module->hide_enable_button ? "non_raw" : "raw");
+    gtk_stack_set_visible_child_name(GTK_STACK(self->widget), self->hide_enable_button ? "non_raw" : "raw");
   }
 
-  module->default_enabled = FALSE;
+  self->default_enabled = FALSE;
 }
 
-void commit_params(struct dt_iop_module_t *self, dt_iop_params_t *params, dt_dev_pixelpipe_t *pipe,
+void commit_params(dt_iop_module_t *self, dt_iop_params_t *params, dt_dev_pixelpipe_t *pipe,
                    dt_dev_pixelpipe_iop_t *piece)
 {
   dt_iop_rawdenoise_params_t *p = (dt_iop_rawdenoise_params_t *)params;
-  dt_iop_rawdenoise_data_t *d = (dt_iop_rawdenoise_data_t *)piece->data;
+  dt_iop_rawdenoise_data_t *d = piece->data;
 
   d->threshold = p->threshold;
 
@@ -560,10 +536,10 @@ void commit_params(struct dt_iop_module_t *self, dt_iop_params_t *params, dt_dev
     piece->enabled = FALSE;
 }
 
-void init_pipe(struct dt_iop_module_t *self, dt_dev_pixelpipe_t *pipe, dt_dev_pixelpipe_iop_t *piece)
+void init_pipe(dt_iop_module_t *self, dt_dev_pixelpipe_t *pipe, dt_dev_pixelpipe_iop_t *piece)
 {
-  dt_iop_rawdenoise_data_t *d = (dt_iop_rawdenoise_data_t *)malloc(sizeof(dt_iop_rawdenoise_data_t));
-  const dt_iop_rawdenoise_params_t *const default_params = (dt_iop_rawdenoise_params_t *)self->default_params;
+  dt_iop_rawdenoise_data_t *d = malloc(sizeof(dt_iop_rawdenoise_data_t));
+  const dt_iop_rawdenoise_params_t *const default_params = self->default_params;
 
   piece->data = (void *)d;
   for(int ch = 0; ch < DT_RAWDENOISE_NONE; ch++)
@@ -574,9 +550,9 @@ void init_pipe(struct dt_iop_module_t *self, dt_dev_pixelpipe_t *pipe, dt_dev_pi
   }
 }
 
-void cleanup_pipe(struct dt_iop_module_t *self, dt_dev_pixelpipe_t *pipe, dt_dev_pixelpipe_iop_t *piece)
+void cleanup_pipe(dt_iop_module_t *self, dt_dev_pixelpipe_t *pipe, dt_dev_pixelpipe_iop_t *piece)
 {
-  dt_iop_rawdenoise_data_t *d = (dt_iop_rawdenoise_data_t *)(piece->data);
+  dt_iop_rawdenoise_data_t *d = piece->data;
   for(int ch = 0; ch < DT_RAWDENOISE_NONE; ch++) dt_draw_curve_destroy(d->curve[ch]);
   free(piece->data);
   piece->data = NULL;
@@ -584,7 +560,8 @@ void cleanup_pipe(struct dt_iop_module_t *self, dt_dev_pixelpipe_t *pipe, dt_dev
 
 void gui_update(dt_iop_module_t *self)
 {
-  gtk_widget_queue_draw(self->widget);
+  dt_iop_rawdenoise_gui_data_t *g = self->gui_data;
+  gtk_widget_queue_draw(GTK_WIDGET(g->area));
 }
 
 static void dt_iop_rawdenoise_get_params(dt_iop_rawdenoise_params_t *p, const int ch, const double mouse_x,
@@ -597,17 +574,16 @@ static void dt_iop_rawdenoise_get_params(dt_iop_rawdenoise_params_t *p, const in
   }
 }
 
-static gboolean rawdenoise_draw(GtkWidget *widget, cairo_t *crf, gpointer user_data)
+static gboolean rawdenoise_draw(GtkWidget *widget, cairo_t *crf, dt_iop_module_t *self)
 {
-  dt_iop_module_t *self = (dt_iop_module_t *)user_data;
-  dt_iop_rawdenoise_gui_data_t *c = (dt_iop_rawdenoise_gui_data_t *)self->gui_data;
+  dt_iop_rawdenoise_gui_data_t *g = self->gui_data;
   dt_iop_rawdenoise_params_t p = *(dt_iop_rawdenoise_params_t *)self->params;
 
-  int ch = (int)c->channel;
-  dt_draw_curve_set_point(c->transition_curve, 0, p.x[ch][DT_IOP_RAWDENOISE_BANDS - 2] - 1.0, p.y[ch][0]);
+  int ch = (int)g->channel;
+  dt_draw_curve_set_point(g->transition_curve, 0, p.x[ch][DT_IOP_RAWDENOISE_BANDS - 2] - 1.0, p.y[ch][0]);
   for(int k = 0; k < DT_IOP_RAWDENOISE_BANDS; k++)
-    dt_draw_curve_set_point(c->transition_curve, k + 1, p.x[ch][k], p.y[ch][k]);
-  dt_draw_curve_set_point(c->transition_curve, DT_IOP_RAWDENOISE_BANDS + 1, p.x[ch][1] + 1.0,
+    dt_draw_curve_set_point(g->transition_curve, k + 1, p.x[ch][k], p.y[ch][k]);
+  dt_draw_curve_set_point(g->transition_curve, DT_IOP_RAWDENOISE_BANDS + 1, p.x[ch][1] + 1.0,
                           p.y[ch][DT_IOP_RAWDENOISE_BANDS - 1]);
 
   const int inset = DT_IOP_RAWDENOISE_INSET;
@@ -638,25 +614,25 @@ static gboolean rawdenoise_draw(GtkWidget *widget, cairo_t *crf, gpointer user_d
   cairo_set_source_rgb(cr, .1, .1, .1);
   dt_draw_grid(cr, 8, 0, 0, width, height);
 
-  if(c->mouse_y > 0 || c->dragging)
+  if(g->mouse_y > 0 || g->dragging)
   {
     // draw min/max curves:
-    dt_iop_rawdenoise_get_params(&p, c->channel, c->mouse_x, 1., c->mouse_radius);
-    dt_draw_curve_set_point(c->transition_curve, 0, p.x[ch][DT_IOP_RAWDENOISE_BANDS - 2] - 1.0, p.y[ch][0]);
+    dt_iop_rawdenoise_get_params(&p, g->channel, g->mouse_x, 1., g->mouse_radius);
+    dt_draw_curve_set_point(g->transition_curve, 0, p.x[ch][DT_IOP_RAWDENOISE_BANDS - 2] - 1.0, p.y[ch][0]);
     for(int k = 0; k < DT_IOP_RAWDENOISE_BANDS; k++)
-      dt_draw_curve_set_point(c->transition_curve, k + 1, p.x[ch][k], p.y[ch][k]);
-    dt_draw_curve_set_point(c->transition_curve, DT_IOP_RAWDENOISE_BANDS + 1, p.x[ch][1] + 1.0,
+      dt_draw_curve_set_point(g->transition_curve, k + 1, p.x[ch][k], p.y[ch][k]);
+    dt_draw_curve_set_point(g->transition_curve, DT_IOP_RAWDENOISE_BANDS + 1, p.x[ch][1] + 1.0,
                             p.y[ch][DT_IOP_RAWDENOISE_BANDS - 1]);
-    dt_draw_curve_calc_values(c->transition_curve, 0.0, 1.0, DT_IOP_RAWDENOISE_RES, c->draw_min_xs, c->draw_min_ys);
+    dt_draw_curve_calc_values(g->transition_curve, 0.0, 1.0, DT_IOP_RAWDENOISE_RES, g->draw_min_xs, g->draw_min_ys);
 
     p = *(dt_iop_rawdenoise_params_t *)self->params;
-    dt_iop_rawdenoise_get_params(&p, c->channel, c->mouse_x, .0, c->mouse_radius);
-    dt_draw_curve_set_point(c->transition_curve, 0, p.x[ch][DT_IOP_RAWDENOISE_BANDS - 2] - 1.0, p.y[ch][0]);
+    dt_iop_rawdenoise_get_params(&p, g->channel, g->mouse_x, .0, g->mouse_radius);
+    dt_draw_curve_set_point(g->transition_curve, 0, p.x[ch][DT_IOP_RAWDENOISE_BANDS - 2] - 1.0, p.y[ch][0]);
     for(int k = 0; k < DT_IOP_RAWDENOISE_BANDS; k++)
-      dt_draw_curve_set_point(c->transition_curve, k + 1, p.x[ch][k], p.y[ch][k]);
-    dt_draw_curve_set_point(c->transition_curve, DT_IOP_RAWDENOISE_BANDS + 1, p.x[ch][1] + 1.0,
+      dt_draw_curve_set_point(g->transition_curve, k + 1, p.x[ch][k], p.y[ch][k]);
+    dt_draw_curve_set_point(g->transition_curve, DT_IOP_RAWDENOISE_BANDS + 1, p.x[ch][1] + 1.0,
                             p.y[ch][DT_IOP_RAWDENOISE_BANDS - 1]);
-    dt_draw_curve_calc_values(c->transition_curve, 0.0, 1.0, DT_IOP_RAWDENOISE_RES, c->draw_max_xs, c->draw_max_ys);
+    dt_draw_curve_calc_values(g->transition_curve, 0.0, 1.0, DT_IOP_RAWDENOISE_RES, g->draw_max_xs, g->draw_max_ys);
   }
 
   cairo_save(cr);
@@ -670,7 +646,7 @@ static gboolean rawdenoise_draw(GtkWidget *widget, cairo_t *crf, gpointer user_d
   for(int i = 0; i < DT_RAWDENOISE_NONE; i++)
   {
     // draw curves, selected last
-    ch = ((int)c->channel + i + 1) % DT_RAWDENOISE_NONE;
+    ch = ((int)g->channel + i + 1) % DT_RAWDENOISE_NONE;
     float alpha = 0.3;
     if(i == DT_RAWDENOISE_NONE - 1) alpha = 1.0;
     switch(ch)
@@ -690,50 +666,50 @@ static gboolean rawdenoise_draw(GtkWidget *widget, cairo_t *crf, gpointer user_d
     }
 
     p = *(dt_iop_rawdenoise_params_t *)self->params;
-    dt_draw_curve_set_point(c->transition_curve, 0, p.x[ch][DT_IOP_RAWDENOISE_BANDS - 2] - 1.0, p.y[ch][0]);
+    dt_draw_curve_set_point(g->transition_curve, 0, p.x[ch][DT_IOP_RAWDENOISE_BANDS - 2] - 1.0, p.y[ch][0]);
     for(int k = 0; k < DT_IOP_RAWDENOISE_BANDS; k++)
-      dt_draw_curve_set_point(c->transition_curve, k + 1, p.x[ch][k], p.y[ch][k]);
-    dt_draw_curve_set_point(c->transition_curve, DT_IOP_RAWDENOISE_BANDS + 1, p.x[ch][1] + 1.0,
+      dt_draw_curve_set_point(g->transition_curve, k + 1, p.x[ch][k], p.y[ch][k]);
+    dt_draw_curve_set_point(g->transition_curve, DT_IOP_RAWDENOISE_BANDS + 1, p.x[ch][1] + 1.0,
                             p.y[ch][DT_IOP_RAWDENOISE_BANDS - 1]);
-    dt_draw_curve_calc_values(c->transition_curve, 0.0, 1.0, DT_IOP_RAWDENOISE_RES, c->draw_xs, c->draw_ys);
-    cairo_move_to(cr, 0 * width / (float)(DT_IOP_RAWDENOISE_RES - 1), -height * c->draw_ys[0]);
+    dt_draw_curve_calc_values(g->transition_curve, 0.0, 1.0, DT_IOP_RAWDENOISE_RES, g->draw_xs, g->draw_ys);
+    cairo_move_to(cr, 0 * width / (float)(DT_IOP_RAWDENOISE_RES - 1), -height * g->draw_ys[0]);
     for(int k = 1; k < DT_IOP_RAWDENOISE_RES; k++)
-      cairo_line_to(cr, k * width / (float)(DT_IOP_RAWDENOISE_RES - 1), -height * c->draw_ys[k]);
+      cairo_line_to(cr, k * width / (float)(DT_IOP_RAWDENOISE_RES - 1), -height * g->draw_ys[k]);
     cairo_stroke(cr);
   }
 
-  ch = c->channel;
+  ch = g->channel;
   // draw dots on knots
   cairo_set_source_rgb(cr, 0.7, 0.7, 0.7);
   cairo_set_line_width(cr, DT_PIXEL_APPLY_DPI(1.));
   for(int k = 0; k < DT_IOP_RAWDENOISE_BANDS; k++)
   {
     cairo_arc(cr, width * p.x[ch][k], -height * p.y[ch][k], DT_PIXEL_APPLY_DPI(3.0), 0.0, 2.0 * M_PI);
-    if(c->x_move == k)
+    if(g->x_move == k)
       cairo_fill(cr);
     else
       cairo_stroke(cr);
   }
 
-  if(c->mouse_y > 0 || c->dragging)
+  if(g->mouse_y > 0 || g->dragging)
   {
     // draw min/max, if selected
     cairo_set_source_rgba(cr, .7, .7, .7, .6);
-    cairo_move_to(cr, 0, -height * c->draw_min_ys[0]);
+    cairo_move_to(cr, 0, -height * g->draw_min_ys[0]);
     for(int k = 1; k < DT_IOP_RAWDENOISE_RES; k++)
-      cairo_line_to(cr, k * width / (float)(DT_IOP_RAWDENOISE_RES - 1), -height * c->draw_min_ys[k]);
+      cairo_line_to(cr, k * width / (float)(DT_IOP_RAWDENOISE_RES - 1), -height * g->draw_min_ys[k]);
     for(int k = DT_IOP_RAWDENOISE_RES - 1; k >= 0; k--)
-      cairo_line_to(cr, k * width / (float)(DT_IOP_RAWDENOISE_RES - 1), -height * c->draw_max_ys[k]);
+      cairo_line_to(cr, k * width / (float)(DT_IOP_RAWDENOISE_RES - 1), -height * g->draw_max_ys[k]);
     cairo_close_path(cr);
     cairo_fill(cr);
     // draw mouse focus circle
     cairo_set_source_rgba(cr, .9, .9, .9, .5);
-    const float pos = DT_IOP_RAWDENOISE_RES * c->mouse_x;
+    const float pos = DT_IOP_RAWDENOISE_RES * g->mouse_x;
     int k = (int)pos;
     const float f = k - pos;
     if(k >= DT_IOP_RAWDENOISE_RES - 1) k = DT_IOP_RAWDENOISE_RES - 2;
-    float ht = -height * (f * c->draw_ys[k] + (1 - f) * c->draw_ys[k + 1]);
-    cairo_arc(cr, c->mouse_x * width, ht, c->mouse_radius * width, 0, 2. * M_PI);
+    float ht = -height * (f * g->draw_ys[k] + (1 - f) * g->draw_ys[k + 1]);
+    cairo_arc(cr, g->mouse_x * width, ht, g->mouse_radius * width, 0, 2. * M_PI);
     cairo_stroke(cr);
   }
 
@@ -751,7 +727,7 @@ static gboolean rawdenoise_draw(GtkWidget *widget, cairo_t *crf, gpointer user_d
   pango_layout_set_font_description(layout, desc);
   cairo_set_source_rgb(cr, .1, .1, .1);
 
-  pango_layout_set_text(layout, _("coarse"), -1);
+  pango_layout_set_text(layout, C_("graph", "coarse"), -1);
   pango_layout_get_pixel_extents(layout, &ink, NULL);
   cairo_move_to(cr, .02 * width - ink.y, .5 * (height + ink.width));
   cairo_save(cr);
@@ -787,166 +763,165 @@ static gboolean rawdenoise_draw(GtkWidget *widget, cairo_t *crf, gpointer user_d
   return FALSE;
 }
 
-static gboolean rawdenoise_motion_notify(GtkWidget *widget, GdkEventMotion *event, gpointer user_data)
+static gboolean rawdenoise_motion_notify(GtkWidget *widget, GdkEventMotion *event, dt_iop_module_t *self)
 {
-  dt_iop_module_t *self = (dt_iop_module_t *)user_data;
-  dt_iop_rawdenoise_gui_data_t *c = (dt_iop_rawdenoise_gui_data_t *)self->gui_data;
-  dt_iop_rawdenoise_params_t *p = (dt_iop_rawdenoise_params_t *)self->params;
+  dt_iop_rawdenoise_gui_data_t *g = self->gui_data;
+  dt_iop_rawdenoise_params_t *p = self->params;
   const int inset = DT_IOP_RAWDENOISE_INSET;
   GtkAllocation allocation;
   gtk_widget_get_allocation(widget, &allocation);
   int height = allocation.height - 2 * inset, width = allocation.width - 2 * inset;
-  if(!c->dragging) c->mouse_x = CLAMP(event->x - inset, 0, width) / (float)width;
-  c->mouse_y = 1.0 - CLAMP(event->y - inset, 0, height) / (float)height;
-  if(c->dragging)
+  if(!g->dragging) g->mouse_x = CLAMP(event->x - inset, 0, width) / (float)width;
+  g->mouse_y = 1.0 - CLAMP(event->y - inset, 0, height) / (float)height;
+  if(g->dragging)
   {
-    *p = c->drag_params;
-    if(c->x_move < 0)
+    *p = g->drag_params;
+    if(g->x_move < 0)
     {
-      dt_iop_rawdenoise_get_params(p, c->channel, c->mouse_x, c->mouse_y + c->mouse_pick, c->mouse_radius);
+      dt_iop_rawdenoise_get_params(p, g->channel, g->mouse_x, g->mouse_y + g->mouse_pick, g->mouse_radius);
     }
     gtk_widget_queue_draw(widget);
-    dt_dev_add_history_item_target(darktable.develop, self, TRUE, widget + c->channel);
+    dt_dev_add_history_item_target(darktable.develop, self, TRUE, widget + g->channel);
   }
   else
   {
-    c->x_move = -1;
+    g->x_move = -1;
     gtk_widget_queue_draw(widget);
   }
   return TRUE;
 }
 
-static gboolean rawdenoise_button_press(GtkWidget *widget, GdkEventButton *event, gpointer user_data)
+static gboolean rawdenoise_button_press(GtkWidget *widget, GdkEventButton *event, dt_iop_module_t *self)
 {
-  dt_iop_module_t *self = (dt_iop_module_t *)user_data;
-  dt_iop_rawdenoise_gui_data_t *c = (dt_iop_rawdenoise_gui_data_t *)self->gui_data;
-  const int ch = c->channel;
-  if(event->button == 1 && event->type == GDK_2BUTTON_PRESS)
+  dt_iop_rawdenoise_gui_data_t *g = self->gui_data;
+  const int ch = g->channel;
+  if(event->button == GDK_BUTTON_PRIMARY && event->type == GDK_2BUTTON_PRESS)
   {
     // reset current curve
-    dt_iop_rawdenoise_params_t *p = (dt_iop_rawdenoise_params_t *)self->params;
-    const dt_iop_rawdenoise_params_t *const d = (dt_iop_rawdenoise_params_t *)self->default_params;
+    dt_iop_rawdenoise_params_t *p = self->params;
+    const dt_iop_rawdenoise_params_t *const d = self->default_params;
     for(int k = 0; k < DT_IOP_RAWDENOISE_BANDS; k++)
     {
       p->x[ch][k] = d->x[ch][k];
       p->y[ch][k] = d->y[ch][k];
     }
     dt_dev_add_history_item_target(darktable.develop, self, TRUE, widget + ch);
-    gtk_widget_queue_draw(self->widget);
+    gtk_widget_queue_draw(GTK_WIDGET(g->area));
   }
-  else if(event->button == 1)
+  else if(event->button == GDK_BUTTON_PRIMARY)
   {
-    c->drag_params = *(dt_iop_rawdenoise_params_t *)self->params;
+    g->drag_params = *(dt_iop_rawdenoise_params_t *)self->params;
     const int inset = DT_IOP_RAWDENOISE_INSET;
     GtkAllocation allocation;
     gtk_widget_get_allocation(widget, &allocation);
     int height = allocation.height - 2 * inset, width = allocation.width - 2 * inset;
-    c->mouse_pick
-        = dt_draw_curve_calc_value(c->transition_curve, CLAMP(event->x - inset, 0, width) / (float)width);
-    c->mouse_pick -= 1.0 - CLAMP(event->y - inset, 0, height) / (float)height;
-    c->dragging = 1;
+    g->mouse_pick
+        = dt_draw_curve_calc_value(g->transition_curve, CLAMP(event->x - inset, 0, width) / (float)width);
+    g->mouse_pick -= 1.0 - CLAMP(event->y - inset, 0, height) / (float)height;
+    g->dragging = 1;
     return TRUE;
   }
   return FALSE;
 }
 
-static gboolean rawdenoise_button_release(GtkWidget *widget, GdkEventButton *event, gpointer user_data)
+static gboolean rawdenoise_button_release(GtkWidget *widget, GdkEventButton *event, dt_iop_module_t *self)
 {
-  if(event->button == 1)
+  if(event->button == GDK_BUTTON_PRIMARY)
   {
-    dt_iop_module_t *self = (dt_iop_module_t *)user_data;
-    dt_iop_rawdenoise_gui_data_t *c = (dt_iop_rawdenoise_gui_data_t *)self->gui_data;
-    c->dragging = 0;
+    dt_iop_rawdenoise_gui_data_t *g = self->gui_data;
+    g->dragging = 0;
     return TRUE;
   }
   return FALSE;
 }
 
-static gboolean rawdenoise_leave_notify(GtkWidget *widget, GdkEventCrossing *event, gpointer user_data)
+static gboolean rawdenoise_leave_notify(GtkWidget *widget, GdkEventCrossing *event, dt_iop_module_t *self)
 {
-  dt_iop_module_t *self = (dt_iop_module_t *)user_data;
-  dt_iop_rawdenoise_gui_data_t *c = (dt_iop_rawdenoise_gui_data_t *)self->gui_data;
-  if(!c->dragging) c->mouse_y = -1.0;
+  dt_iop_rawdenoise_gui_data_t *g = self->gui_data;
+  if(!g->dragging) g->mouse_y = -1.0;
   gtk_widget_queue_draw(widget);
   return TRUE;
 }
 
-static gboolean rawdenoise_scrolled(GtkWidget *widget, GdkEventScroll *event, gpointer user_data)
+static gboolean rawdenoise_scrolled(GtkWidget *widget, GdkEventScroll *event, dt_iop_module_t *self)
 {
-  dt_iop_module_t *self = (dt_iop_module_t *)user_data;
-  dt_iop_rawdenoise_gui_data_t *c = (dt_iop_rawdenoise_gui_data_t *)self->gui_data;
+  dt_iop_rawdenoise_gui_data_t *g = self->gui_data;
 
   if(dt_gui_ignore_scroll(event)) return FALSE;
 
+  if(dt_modifier_is(event->state, GDK_MOD1_MASK))
+    return gtk_widget_event(GTK_WIDGET(g->channel_tabs), (GdkEvent*)event);
+
   int delta_y;
   if(dt_gui_get_scroll_unit_delta(event, &delta_y))
   {
-    c->mouse_radius = CLAMP(c->mouse_radius * (1.0 + 0.1 * delta_y), 0.2 / DT_IOP_RAWDENOISE_BANDS, 1.0);
+    g->mouse_radius = CLAMP(g->mouse_radius * (1.0 + 0.1 * delta_y), 0.2 / DT_IOP_RAWDENOISE_BANDS, 1.0);
     gtk_widget_queue_draw(widget);
   }
 
   return TRUE;
 }
 
-static void rawdenoise_tab_switch(GtkNotebook *notebook, GtkWidget *page, guint page_num, gpointer user_data)
+static void rawdenoise_tab_switch(GtkNotebook *notebook, GtkWidget *page, guint page_num, dt_iop_module_t *self)
 {
-  dt_iop_module_t *self = (dt_iop_module_t *)user_data;
   if(darktable.gui->reset) return;
-  dt_iop_rawdenoise_gui_data_t *c = (dt_iop_rawdenoise_gui_data_t *)self->gui_data;
-  c->channel = (dt_iop_rawdenoise_channel_t)page_num;
-  gtk_widget_queue_draw(self->widget);
+  dt_iop_rawdenoise_gui_data_t *g = self->gui_data;
+  g->channel = (dt_iop_rawdenoise_channel_t)page_num;
+  gtk_widget_queue_draw(GTK_WIDGET(g->area));
 }
 
 void gui_init(dt_iop_module_t *self)
 {
-  dt_iop_rawdenoise_gui_data_t *c = IOP_GUI_ALLOC(rawdenoise);
-  const dt_iop_rawdenoise_params_t *const p = (dt_iop_rawdenoise_params_t *)self->default_params;
+  dt_iop_rawdenoise_gui_data_t *g = IOP_GUI_ALLOC(rawdenoise);
+  const dt_iop_rawdenoise_params_t *const p = self->default_params;
 
-  c->channel = dt_conf_get_int("plugins/darkroom/rawdenoise/gui_channel");
-  c->channel_tabs = GTK_NOTEBOOK(gtk_notebook_new());
-  dt_action_define_iop(self, NULL, N_("channel"), GTK_WIDGET(c->channel_tabs), &dt_action_def_tabs_all_rgb);
+  g->channel = dt_conf_get_int("plugins/darkroom/rawdenoise/gui_channel");
+  g->channel_tabs = GTK_NOTEBOOK(gtk_notebook_new());
+  dt_action_define_iop(self, NULL, N_("channel"), GTK_WIDGET(g->channel_tabs), &dt_action_def_tabs_all_rgb);
 
-  dt_ui_notebook_page(c->channel_tabs, N_("all"), NULL);
-  dt_ui_notebook_page(c->channel_tabs, N_("R"), NULL);
-  dt_ui_notebook_page(c->channel_tabs, N_("G"), NULL);
-  dt_ui_notebook_page(c->channel_tabs, N_("B"), NULL);
+  dt_ui_notebook_page(g->channel_tabs, N_("all"), NULL);
+  dt_ui_notebook_page(g->channel_tabs, N_("R"), NULL);
+  dt_ui_notebook_page(g->channel_tabs, N_("G"), NULL);
+  dt_ui_notebook_page(g->channel_tabs, N_("B"), NULL);
 
-  gtk_widget_show(gtk_notebook_get_nth_page(c->channel_tabs, c->channel));
-  gtk_notebook_set_current_page(c->channel_tabs, c->channel);
-  g_signal_connect(G_OBJECT(c->channel_tabs), "switch_page", G_CALLBACK(rawdenoise_tab_switch), self);
+  gtk_widget_show(gtk_notebook_get_nth_page(g->channel_tabs, g->channel));
+  gtk_notebook_set_current_page(g->channel_tabs, g->channel);
+  g_signal_connect(G_OBJECT(g->channel_tabs), "switch_page", G_CALLBACK(rawdenoise_tab_switch), self);
 
-  const int ch = (int)c->channel;
-  c->transition_curve = dt_draw_curve_new(0.0, 1.0, CATMULL_ROM);
-  (void)dt_draw_curve_add_point(c->transition_curve, p->x[ch][DT_IOP_RAWDENOISE_BANDS - 2] - 1.0,
+  const int ch = (int)g->channel;
+  g->transition_curve = dt_draw_curve_new(0.0, 1.0, CATMULL_ROM);
+  (void)dt_draw_curve_add_point(g->transition_curve, p->x[ch][DT_IOP_RAWDENOISE_BANDS - 2] - 1.0,
                                 p->y[ch][DT_IOP_RAWDENOISE_BANDS - 2]);
   for(int k = 0; k < DT_IOP_RAWDENOISE_BANDS; k++)
-    (void)dt_draw_curve_add_point(c->transition_curve, p->x[ch][k], p->y[ch][k]);
-  (void)dt_draw_curve_add_point(c->transition_curve, p->x[ch][1] + 1.0, p->y[ch][1]);
+    (void)dt_draw_curve_add_point(g->transition_curve, p->x[ch][k], p->y[ch][k]);
+  (void)dt_draw_curve_add_point(g->transition_curve, p->x[ch][1] + 1.0, p->y[ch][1]);
 
-  c->mouse_x = c->mouse_y = c->mouse_pick = -1.0;
-  c->dragging = 0;
-  c->x_move = -1;
-  c->mouse_radius = 1.0 / (DT_IOP_RAWDENOISE_BANDS * 2);
+  g->mouse_x = g->mouse_y = g->mouse_pick = -1.0;
+  g->dragging = 0;
+  g->x_move = -1;
+  g->mouse_radius = 1.0 / (DT_IOP_RAWDENOISE_BANDS * 2);
 
   GtkWidget *box_raw = self->widget = gtk_box_new(GTK_ORIENTATION_VERTICAL, DT_BAUHAUS_SPACE);
 
-  c->area = GTK_DRAWING_AREA(dt_ui_resize_wrap(NULL, 0, "plugins/darkroom/rawdenoise/aspect_percent"));
-  g_object_set_data(G_OBJECT(c->area), "iop-instance", self);
-  dt_action_define_iop(self, NULL, N_("graph"), GTK_WIDGET(c->area), NULL);
+  g->area = GTK_DRAWING_AREA(dt_ui_resize_wrap(NULL,
+                                               0,
+                                               "plugins/darkroom/rawdenoise/graphheight"));
+  g_object_set_data(G_OBJECT(g->area), "iop-instance", self);
+  dt_action_define_iop(self, NULL, N_("graph"), GTK_WIDGET(g->area), NULL);
 
-  gtk_box_pack_start(GTK_BOX(box_raw), GTK_WIDGET(c->channel_tabs), FALSE, FALSE, 0);
-  gtk_box_pack_start(GTK_BOX(box_raw), GTK_WIDGET(c->area), FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(box_raw), GTK_WIDGET(g->channel_tabs), FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(box_raw), GTK_WIDGET(g->area), FALSE, FALSE, 0);
 
-  g_signal_connect(G_OBJECT(c->area), "draw", G_CALLBACK(rawdenoise_draw), self);
-  g_signal_connect(G_OBJECT(c->area), "button-press-event", G_CALLBACK(rawdenoise_button_press), self);
-  g_signal_connect(G_OBJECT(c->area), "button-release-event", G_CALLBACK(rawdenoise_button_release), self);
-  g_signal_connect(G_OBJECT(c->area), "motion-notify-event", G_CALLBACK(rawdenoise_motion_notify), self);
-  g_signal_connect(G_OBJECT(c->area), "leave-notify-event", G_CALLBACK(rawdenoise_leave_notify), self);
-  g_signal_connect(G_OBJECT(c->area), "scroll-event", G_CALLBACK(rawdenoise_scrolled), self);
+  g_signal_connect(G_OBJECT(g->area), "draw", G_CALLBACK(rawdenoise_draw), self);
+  g_signal_connect(G_OBJECT(g->area), "button-press-event", G_CALLBACK(rawdenoise_button_press), self);
+  g_signal_connect(G_OBJECT(g->area), "button-release-event", G_CALLBACK(rawdenoise_button_release), self);
+  g_signal_connect(G_OBJECT(g->area), "motion-notify-event", G_CALLBACK(rawdenoise_motion_notify), self);
+  g_signal_connect(G_OBJECT(g->area), "leave-notify-event", G_CALLBACK(rawdenoise_leave_notify), self);
+  g_signal_connect(G_OBJECT(g->area), "scroll-event", G_CALLBACK(rawdenoise_scrolled), self);
 
-  c->threshold = dt_bauhaus_slider_from_params(self, "threshold");
-  dt_bauhaus_slider_set_soft_max(c->threshold, 0.1);
-  dt_bauhaus_slider_set_digits(c->threshold, 3);
+  g->threshold = dt_bauhaus_slider_from_params(self, "threshold");
+  dt_bauhaus_slider_set_soft_max(g->threshold, 0.1);
+  dt_bauhaus_slider_set_digits(g->threshold, 3);
 
   // start building top level widget
   self->widget = gtk_stack_new();
@@ -960,11 +935,9 @@ void gui_init(dt_iop_module_t *self)
 
 void gui_cleanup(dt_iop_module_t *self)
 {
-  dt_iop_rawdenoise_gui_data_t *c = (dt_iop_rawdenoise_gui_data_t *)self->gui_data;
-  dt_conf_set_int("plugins/darkroom/rawdenoise/gui_channel", c->channel);
-  dt_draw_curve_destroy(c->transition_curve);
-
-  IOP_GUI_FREE;
+  dt_iop_rawdenoise_gui_data_t *g = self->gui_data;
+  dt_conf_set_int("plugins/darkroom/rawdenoise/gui_channel", g->channel);
+  dt_draw_curve_destroy(g->transition_curve);
 }
 // clang-format off
 // modelines: These editor modelines have been set for all relevant files by tools/update_modelines.py
